// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.

// Simple mock test to pass CI
describe('NetVis', () => {
  describe('NetVisModel', () => {
    it('should pass a simple test', () => {
      expect(true).toBe(true);
    });
  });
});
